# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mkdocs_awesome_pages_plugin']

package_data = \
{'': ['*']}

install_requires = \
['mkdocs>=1', 'wcmatch>=7']

entry_points = \
{'mkdocs.plugins': ['awesome-pages = '
                    'mkdocs_awesome_pages_plugin.plugin:AwesomePagesPlugin']}

setup_kwargs = {
    'name': 'mkdocs-awesome-pages-plugin',
    'version': '2.7.0',
    'description': 'An MkDocs plugin that simplifies configuring page titles and their order',
    'long_description': '# MkDocs Awesome Pages Plugin [![Tests Status][status-tests-badge]][status-tests-link]\n\n*An MkDocs plugin that simplifies configuring page titles and their order*\n\nThe awesome-pages plugin allows you to customize how your pages show up the navigation of your MkDocs without having to configure the full structure in your `mkdocs.yml`. It gives you detailed control using a small configuration file directly placed in the relevant directory of your documentation.\n\n> **Note:** This plugin won\'t do anything if your `mkdocs.yml` defines a `nav` or `pages` entry. To make use of the features listed below, you\'ll either have to remove the entry completely or [add a `...` entry to it](#combine-custom-navigation--file-structure).\n\n<br/>\n\n## Installation\n\n> **Note:** This package requires Python >=3.5 and MkDocs version 1.0 or higher.  \n> If you\'re still on MkDocs 0.17 use [version 1 of this plugin][github-v1].\n\nInstall the package with pip:\n\n```bash\npip install mkdocs-awesome-pages-plugin\n```\n\nEnable the plugin in your `mkdocs.yml`:\n\n```yaml\nplugins:\n    - search\n    - awesome-pages\n```\n\n> **Note:** If you have no `plugins` entry in your config file yet, you\'ll likely also want to add the `search` plugin. MkDocs enables it by default if there is no `plugins` entry set, but now you have to enable it explicitly.\n\nMore information about plugins in the [MkDocs documentation][mkdocs-plugins]\n\n<br/>\n\n## Features\n\n### Customize Navigation\n\nCreate a file named `.pages` in a directory and use the `nav` attribute to customize the navigation on that level. List the files and subdirectories in the order that they should appear in the navigation.\n\n```yaml\nnav:\n    - subdirectory\n    - page1.md\n    - page2.md\n```\n\n#### Rest\n\nPages or sections that are not mentioned in the list will not appear in the navigation. However, you may include a `...`  entry to specify where all remaining items should be inserted.\n\n```yaml\nnav:\n    - introduction.md\n    - ...\n    - summary.md\n```\n\nFurthermore, it is possible to filter the remaining items using glob patterns or regular expressions. For example to match only the Markdown files starting with `introduction-`.\n\n```yaml\nnav:\n    - ... | introduction-*.md\n    - ...\n    - summary.md\n```\n\n> **Note:** The pattern is checked against the basename (folder- / filename) of remaining items - not their whole path.\n\nFor more details refer to the [Rest Filter Patterns](#rest-filter-patterns) section below.\n\n#### Titles\n\nYou can optionally specify a title for the navigation entry.\n\n```yaml\nnav:\n    - ...\n    - First page: page1.md\n```\n\n> **Note:** Specifying a title for a directory containing a `.pages` file that defines a `title` has no effect.\n\n#### Links\n\nYou can also use the `nav` attribute to add additional links to the navigation.\n\n```yaml\nnav:\n    - ...\n    - Link Title: https://lukasgeiter.com\n```\n\n#### Sections\n\nYou can group items by creating new sections.\n\n```yaml\nnav:\n    - introduction.md\n    - Section 1:\n        - page1.md\n        - page2.md\n    - Section 2:\n        - ...\n```\n\n### Change Sort Order\n\nCreate a file named `.pages` in a directory and set the `order` attribute to `asc` or `desc` to change the order of navigation items.\n\n```yaml\norder: desc\n```\n\n> **Note:** Unlike the default order, this does not distinguish between files and directories. Therefore pages and sections might get mixed.\n\n### Collapse Single Nested Pages\n\n> **Note:** This feature is disabled by default. More on how to use it below\n\nIf you have directories that only contain a single page, awesome-pages can "collapse" them, so the folder doesn\'t show up in the navigation.\n\nFor example if you have the following file structure:\n\n```yaml\ndocs/\n├─ section1/\n│  ├─ img/\n│  │  ├─ image1.png\n│  │  └─ image2.png\n│  └─ index.md # Section 1\n└─ section2/\n   └─ index.md # Section 2\n```\n\nThe pages will appear in your navigation at the root level:\n\n- Section 1\n- Section 2\n\nInstead of how MkDocs would display them by default:\n\n- Section 1\n  - Index\n- Section 2\n  - Index\n\n#### For all pages\n\nCollapsing can be enabled globally using the [`collapse_single_pages` option](#collapse_single_pages) in `mkdocs.yml`\n\n#### For a sub-section\n\nIf you only want to collapse certain pages, create a file called `.pages` in the directory and set `collapse_single_pages` to `true`:\n\n```yaml\ncollapse_single_pages: true\n```\n\nYou may also enable collapsing globally using the plugin option and then use the `.pages` file to prevent certain sub-sections from being collapsed by setting `collapse_single_pages` to `false`.\n\n> **Note:** This feature works recursively. That means it will also collapse multiple levels of single pages.\n\n#### For a single page\n\nIf you want to enable or disable collapsing of a single page, without applying the setting recursively, create a file called `.pages` in the directory and set `collapse` to `true` or `false`:\n\n```yaml\ncollapse: true\n```\n\n### Hide Directory\n\nCreate a file named `.pages` in a directory and set the `hide` attribute to `true` to hide the directory, including all sub-pages and sub-sections, from the navigation:\n\n```yaml\nhide: true\n```\n\n> **Note:** This option only hides the section from the navigation. It will still be included in the build and can be accessed under its URL.\n\n### Set Directory Title\n\nCreate a file named `.pages` in a directory and set the `title` to override the title of that directory in the navigation:\n\n```yaml\ntitle: Page Title\n```\n\n### Arrange Pages\n\n> **Deprecated:** `arrange` will be removed in the next major release - [Use `nav` instead](#customize-navigation).\n\nCreate a file named `.pages` in a directory and set the `arrange` attribute to change the order of how child pages appear in the navigation. This works for actual pages as well as subdirectories.\n\n```yaml\ntitle: Page Title\narrange:\n    - page1.md\n    - page2.md\n    - subdirectory\n```\n\nIf you only specify *some* pages, they will be positioned at the beginning, followed by the other pages in their original order.\n\nYou may also include a `...` entry at some position to specify where the rest of the pages should be inserted:\n\n```yaml\narrange:\n    - introduction.md\n    - ...\n    - summary.md\n```\n\nIn this example `introduction.md` is positioned at the beginning, `summary.md` at the end, and any other pages in between.\n\n### Combine Custom Navigation & File Structure\n\nMkDocs gives you two ways to define the structure of your navigation. Either create a custom navigation manually in `mkdocs.yml` or use the file structure to generate the navigation. This feature makes it possible to combine both methods. Allowing you to manually define parts of your navigation without having to list all files.\n\n> **Note:** You can freely combine this with all the other features of this plugin. However they will only affect the part of the navigation that is not defined manually.\n\nUse the `nav` entry in `mkdocs.yml` to define the custom part of your navigation. Include a `...` entry where you want the navigation tree of all remaining pages to be inserted.\n\nThe following examples are based on this file structure:\n\n```yaml\ndocs/\n├─ introduction.md\n├─ page1.md\n├─ page2.md\n└─ folder/\n   ├─ introduction.md\n   ├─ page3.md\n   └─ page4.md\n```\n\nIf you wanted `introduction.md`, `page1.md` and `page2.md` to appear under their own section you could do this:\n\n```yaml\nnav:\n    - Start:\n        - page1.md\n        - page2.md\n        - summary.md\n    - ...\n```\n\nWhich would result in the following navigation:\n\n- Start\n  - Introduction\n  - Page 1\n  - Page 2\n- Folder\n  - Introduction\n  - Page 3\n  - Page 4\n\nThe `...` entry can also be placed at a deeper level:\n\n```yaml\nnav:\n    - page1.md\n    - Rest:\n        - ...\n```\n\nWhich would result in the following navigation:\n\n- Page 1\n- Rest\n  - Introduction\n  - Page 2\n  - Folder\n    - Introduction\n    - Page 3\n    - Page 4\n\nFurthermore, it is possible to filter the remaining items using glob patterns or regular expressions. For example to match only files named `introduction.md`.\n\n```yaml\nnav:\n    - Introductions:\n        - ... | **/introduction.md\n    - ...\n```\n\nWith the following result:\n\n- Introductions\n    - Introduction\n    - Introduction\n- Page 1\n- Page 2\n- Folder\n    - Page 3\n    - Page 4\n    \n\n> **Note:** The pattern is checked against the path relative to the docs directory.\n\nFor more details refer to the [Rest Filter Patterns](#rest-filter-patterns) section below.\n\nBy default, remaining items keep their hierarchical structure. You may add `flat` to flatten all the matching pages:\n\n```yaml\nnav:\n    - page1.md\n    - Rest:\n        - ... | flat | **/introduction.md\n        - ... | flat\n```\n\n- Page 1\n- Rest\n    - Introduction\n    - Introduction\n    - Page 2\n    - Page 3\n    - Page 4\n\n<br/>\n\n## Rest Filter Patterns\n\nIn all places where the rest entry (`...`) is allowed, you can also include a glob pattern or regular expression to filter the items to be displayed.\n\n```yaml\nnav:\n    - ... | page-*.md\n    - ... | regex=page-[0-9]+.md\n```\n\nThe filter only operates on remaining items. This means it will not include items that are explicitly listed in the navigation or items that are matched by another filter that appears earlier in the configuration.\n\nYou may also include a rest entry without filter to act as a catch-all, inserting everything that is not matched by a filter.\n\n### Syntax Details\n\nUnless the filter starts with `regex=` it is interpreted as glob pattern, however you may also explicitly say so using `glob=`. The spaces around `...` are optional but recommended for readability.\n\n> **Note:** Depending on the characters in your filter, you might also need to use quotes around the whole entry.\n\n```yaml\nnav:\n    # equivalent glob entries\n    - ... | page-*.md\n    - ... | glob=page-*.md\n    - ...|page-*.md\n    - \'... | page-*.md\'\n\n    # equivalent regex entries\n    - ... | regex=page-[0-9]+.md\n    - ...|regex=page-[0-9]+.md\n    - \'... | regex=page-[0-9]+.md\'\n```\n\n<br/>\n\n## Options\n\nYou may customize the plugin by passing options in `mkdocs.yml`:\n\n```yaml\nplugins:\n    - awesome-pages:\n        filename: .index\n        collapse_single_pages: true\n        strict: false\n```\n\n### `filename`\n\nName of the file used to configure pages of a directory. Default is `.pages`\n\n### `collapse_single_pages`\n\nEnable the collapsing of single nested pages. Default is `false`\n\n### `strict`\n\nRaise errors instead of warnings when:\n\n- `arrange` entries cannot be found\n- `nav` entries cannot be found\n\nDefault is `true`\n\n<br/>\n\n## Contributing\n\nFrom reporting a bug to submitting a pull request: every contribution is appreciated and welcome.\nReport bugs, ask questions and request features using [Github issues][github-issues].\nIf you want to contribute to the code of this project, please read the [Contribution Guidelines][contributing].\n\n[status-tests-badge]: https://github.com/lukasgeiter/mkdocs-awesome-pages-plugin/actions/workflows/tests.yml/badge.svg\n[status-tests-link]: https://github.com/lukasgeiter/mkdocs-awesome-pages-plugin/actions/workflows/tests.yml\n[mkdocs-plugins]: http://www.mkdocs.org/user-guide/plugins/\n[github-v1]: https://github.com/lukasgeiter/mkdocs-awesome-pages-plugin/tree/v1\n[github-issues]: https://github.com/lukasgeiter/mkdocs-awesome-pages-plugin/issues\n[contributing]: CONTRIBUTING.md\n',
    'author': 'Lukas Geiter',
    'author_email': 'info@lukasgeiter.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/lukasgeiter/mkdocs-awesome-pages-plugin/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6.2',
}


setup(**setup_kwargs)
